decode method

({double lat, double lon}) decode(
  1. int geohash
)
inherited

Decodes a geohash to a (latitude, longitude) record. The result is the exact center of the bounding box for the geohash, returned by bounds function.

Implementation

({double lat, double lon}) decode(T geohash) {
  final b = bounds(geohash);
  return (lat: (b.minLat + b.maxLat) / 2, lon: (b.minLon + b.maxLon) / 2);
}