TooManyGeohashesException class

Thrown when batch geohash calculation returned too many geohashes.

Implemented types

Constructors

TooManyGeohashesException(int count)

Properties

count int
How many hashes were calculated, or planned to be calculated. This number is always over the given limit.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited