count property
How many hashes were calculated, or planned to be calculated. This number is always over the given limit.
Implementation
final int count;
How many hashes were calculated, or planned to be calculated. This number is always over the given limit.
final int count;