Encode a latitude and longitude to a geohash string of given
precision (that is, bit length). To match the precision of
string-based geohashes, keep in mind that every character is 5 bits.
Returns a list of geohashes for the given bounding box. Those geohashes
cover all four corners and everything inbetween. Adjust the limit to throw
a TooManyGeohashesException when the bounds cover too many cells.
Returns a list of geohashes for a circle with a given centre location
and a radius in meters. Assumes the latitude and longitude to be
in EPSG:4326 projection. Will trim the circle if it goes outside the
EPSG:3857 projection boundaries.
Returns all eight neighbours for the given geohash string. It does
call adjacent eight times, so when you don't need every value, maybe
you are better using that function. Although it's a little bit more
efficient by not calculating an adjacent code twice for diagonal directions.