fast_geohash_str library
Enums
- Direction
-
A cardinal direction for calculating an adjacent geohash.
See
adjacent.
Constants
- geohash → const GeohashString
Typedefs
- BoundsRecord = ({double maxLat, double maxLon, double minLat, double minLon})
- A shorthand for the big annotated record for bounding bounds.
Exceptions / Errors
- OutOfWorldBoundsException
- Thrown when trying to calculate a geohash behind the 90° latitude.
- TooManyGeohashesException
- Thrown when batch geohash calculation returned too many geohashes.